@@ -187,4 +187,36 @@ class Devices(AbstractDevices):
         if not res.ok:
             raise Exception(res.text)
 
-        return True
\ No newline at end of file
+        return True
+    
+    def delete(self, device: Union[DeviceId, Device]) -> bool:
+        """Deletes a device.
+
+        Parameters
+        ----------
+        device : DeviceId or Device
+            Device id or Device to delete
+
+        Raises
+        ------
+        Exception
+            If the API request wasn't successful.
+
+        Returns
+        ------
+            None
+        """
+
+        if not device:
+            raise Exception("device is required")
+
+        params = {"device_id": to_device_id(device)}
+        res = requests.post(
+            f"{self.seam.api_url}/devices/delete",
+            headers={"Authorization": f"Bearer {self.seam.api_key}"},
+            params=params,
+        )
+        if not res.ok:
+            raise Exception(res.text)
+
+        return None
\ No newline at end of file
